@@ -13,7 +13,7 @@ import subprocess
 import tempfile
 import textwrap
 import types
-from typing import Iterable, List, Literal, Optional
+from typing import Iterable, List, Optional
 
 
 LOGGER = getLogger(__name__)
@@ -27,20 +27,19 @@ class ShTest:
         command: Command to execute.
         want: Expected output.
         want_returncode: Expected returncode.
-        stream: Which stream to compare with.
+        stderr: Read from stderr instead of stdout.
         source: Source file in which the test is declared.
         lineno: Line number where the test is declared.
         cwd: Working directory.
         tempdir: Use a temporary working directory.
     """
     def __init__(self, command: str, want: str, want_returncode: int = 0,
-                 stream: Literal["stdout", "stderr"] = "stdout", source: Optional[str] = None,
-                 lineno: Optional[int] = None, cwd: Optional[str] = None, tempdir: bool = False) \
-            -> None:
+                 stderr: bool = False, source: Optional[str] = None, lineno: Optional[int] = None,
+                 cwd: Optional[str] = None, tempdir: bool = False) -> None:
         self.command = command
         self.want = want if want.endswith("\n") else want + "\n"
         self.want_returncode = want_returncode
-        self.stream = stream
+        self.stderr = stderr
         self.source = source
         self.lineno = lineno
         self.cwd = cwd
@@ -53,21 +52,23 @@ class ShTest:
         # Resolve the working directory relative to the source document.
         if self.source and self.cwd:
             self.cwd = (Path(self.source).parent / self.cwd).resolve()
+        elif self.source:
+            self.cwd = Path(self.source).parent
 
     def run(self) -> None:
         kwargs = {
             "args": self.command,
             "text": True,
             "shell": True,
-            "stdout": subprocess.PIPE,
-            "stderr": subprocess.PIPE,
+            "stderr" if self.stderr else "stdout": subprocess.PIPE,
         }
+        process: subprocess.CompletedProcess
         if self.tempdir:
             with tempfile.TemporaryDirectory() as tempdir:
                 process = subprocess.run(**kwargs, cwd=tempdir)
         else:
             process = subprocess.run(**kwargs, cwd=self.cwd)
-        got = getattr(process, self.stream)
+        got = strip_colors(process.stderr if self.stderr else process.stdout)
 
         # Create a prefix for messages.
         parts = [
@@ -99,7 +100,7 @@ class ShTest:
         Iterate over all sub-tests of a given node.
         """
         kwargs = {
-            "stream": node["stream"],
+            "stderr": node["stderr"],
             "source": node.source,
             "cwd": node["cwd"],
             "tempdir": node["tempdir"],
@@ -138,10 +139,10 @@ class ShTestError(SphinxError):
 class ShTestDirective(SphinxDirective):
     has_content = True
     option_spec = {
-        'returncode': int,
-        'stream': lambda x: directives.choice(x, ('stderr', 'stdout')),
-        'cwd': str,
-        'tempdir': directives.flag,
+        "returncode": int,
+        "stderr": directives.flag,
+        "cwd": str,
+        "tempdir": directives.flag,
     }
 
     def run(self) -> List[Node]:
@@ -150,12 +151,41 @@ class ShTestDirective(SphinxDirective):
         content = '\n'.join(self.content)
         node = literal_block(
             content, content, shtest=True, language="bash", lineno=self.lineno,
-            stream=self.options.get("stream", "stdout"), cwd=self.options.get("cwd"),
+            stderr="stderr" in self.options, cwd=self.options.get("cwd"),
             returncode=self.options.get("returncode", 0), tempdir="tempdir" in self.options,
         )
         return [node]
 
 
+class ShDirective(SphinxDirective):
+    """
+    Displays shell command output in the documentation.
+    """
+    required_arguments = 1
+    optional_arguments = float("inf")
+    has_content = False
+    option_spec = {
+        "stderr": directives.flag,
+        "cwd": str,
+    }
+
+    def run(self) -> List[Node]:
+        # Run the command and display the output.
+        parent = Path(self.state.document["source"]).parent
+        cwd = (parent / cwd) if (cwd := self.options.get("cwd")) else parent
+        stderr = "stderr" in self.options
+        kwargs = {
+            "args": " ".join(self.arguments),
+            "shell": True,
+            "text": True,
+            "stderr" if stderr else "stdout": subprocess.PIPE,
+        }
+        process = subprocess.run(**kwargs)
+        content = process.stderr if stderr else process.stdout
+        node = literal_block(content, content)
+        return [node]
+
+
 class ShTestBuilder(Builder):
     """
     Runs shell command test snippets in the documentation.
@@ -181,10 +211,23 @@ class ShTestBuilder(Builder):
     def prepare_writing(self, docnames: set[str]) -> None:
         pass
 
-    def get_target_uri(self, docname: str, typ: str = None) -> str:
+    def get_target_uri(self, docname: str, typ: str = None) -> str:  # pragma: no cover
         return ""
 
 
 def setup(app: Sphinx) -> None:
+    app.add_directive("sh", ShDirective)
     app.add_directive("shtest", ShTestDirective)
     app.add_builder(ShTestBuilder)
+
+
+def strip_colors(text: str) -> str:
+    try:
+        import colorama
+
+        for ansi_codes in [colorama.Fore, colorama.Back]:
+            for code in vars(ansi_codes).values():
+                text = text.replace(code, "")
+        return text
+    except ImportError:  # pragma: no cover
+        return text
